@@ -480,7 +480,7 @@ z$methods(
 )
 
 z$methods(
-  show = function(signif.stars = FALSE) {
+  show = function(signif.stars = FALSE, subset = NULL) {
     "Display a Zelig object"
     .self$signif.stars <- signif.stars
     .self$signif.stars.default <- getOption("show.signif.stars")
@@ -495,22 +495,8 @@ z$methods(
       	.self$zelig.out$z.out[[jj]]$call <- .self$zelig.call
       }	
       #############################################################################
-      summ <- .self$zelig.out %>%
-        do(summ = {cat("Model: \n")
-                   if (length(.self$by) == 1) {
-                     if (.self$by == "by") {
-                       cat()
-                     }
-                     else {
-                       print(.[.self$by])
-                     }
-                   } else {
-                     print(.[.self$by])
-                   }
-                   print(base::summary(.$z.out))
-                   })
-        
-      if(.self$mi){
+
+      if((.self$mi) & is.null(subset)){
         cat("Model: Combined Imputations \n")
         vcovlist <-.self$getvcov()
         coeflist <-.self$getcoef()
@@ -543,9 +529,31 @@ z$methods(
         print(results, digits=max(3, getOption("digits") - 3))
         cat("---\nSignif. codes:  '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1\n")
         cat("\n")
+        cat("For results from individual imputed datasets, use summary(x, subset = i:j)\n")
+      }else if ((.self$mi) & !is.null(subset)) {
+        for(i in subset){
+            cat("Imputed Dataset ",i,sep="")
+            print(base::summary(.self$zelig.out$z.out[[i]]))
+        }
+      }else{
+        summ <- .self$zelig.out %>%
+        do(summ = {cat("Model: \n")
+          if (length(.self$by) == 1) {
+              if (.self$by == "by") {
+                  cat()
+              }
+              else {
+                  print(.[.self$by])
+              }
+          } else {
+              print(.[.self$by])
+          }
+          print(base::summary(.$z.out))
+        })
       }
-      
-      if(!is.null(.self$test.statistics$gim.criteria)){
+
+
+      if("gim.criteria" %in% names(.self$test.statistics)){
           if(.self$test.statistics$gim.criteria){
 #               cat("According to the GIM-rule-of-thumb, your model probably has some type of specification error.\n",
 #               "We suggest you run model diagnostics and seek to fix the problem.\n",
@@ -676,7 +684,7 @@ z$methods(
 
 z$methods(
   getpredict = function() {
-    "Get predcted values"
+    "Get predicted values"
     result <- lapply(.self$zelig.out$z.out, predict)
     if ("try-error" %in% class(result))
       stop("'predict' method' not implemented for model '", .self$name, "'")
@@ -685,6 +693,27 @@ z$methods(
   }
 )
 
+z$methods(
+  getqi = function(qi="ev", xvalue="x"){
+    "Get quantities of interest"
+    possiblexvalues <- names(.self$sim.out)
+    if(!(xvalue %in% possiblexvalues)){
+      stop(paste("xvalue must be ", paste(possiblexvalues, collapse=" or ") , ".", sep=""))
+    }
+    possibleqivalues <- names(.self$sim.out[[xvalue]])
+    if(!(qi %in% possibleqivalues)){
+      stop(paste("qi must be ", paste(possibleqivalues, collapse=" or ") , ".", sep=""))
+    }
+
+    if(.self$mi){
+      tempqi <- do.call(rbind, .self$sim.out[[xvalue]][[qi]])
+    } else {
+      tempqi<- .self$sim.out[[xvalue]][[qi]][[1]]
+    }
+    return(tempqi)
+  }
+)
+
 z$methods(
   toJSON = function() {
     "Convert Zelig object to JSON format"
@@ -757,7 +786,12 @@ z$methods(
         .self$setx(x.sim=xtemp)
         .self$sim()
         #temp<-sort( .self$sim.out$x$ev[[1]] )
-        temp<-sort( .self$sim.out$range[[i]]$ev[[1]] )
+        temp<-.self$sim.out$range[[i]]$ev[[1]]
+        # This is for ev's that are a probability distribution across outcomes, like ordered logit/probit
+        if(ncol(temp)>1){
+            temp <- temp %*% as.numeric(colnames(temp))
+        }
+        temp <- sort(temp)
         
         #calculate bounds of expected values
         history.ev[i,1]<-temp[max(round(length(temp)*(alpha.ci/2)),1) ]     # Lower ci bound
@@ -860,43 +894,58 @@ z$methods(
 #   }
 # )
 
+
+#' Summary method for Zelig objects"
+#' @param object An Object of Class Zelig
+#' @param ... Additional parameters to be passed to summary
 setMethod("summary", "Zelig",
           function(object, ...) {
             object$summarize(...)
           }
 )
 
+#' Plot method for Zelig objects
+#' @param x An Object of Class Zelig
+#' @param y unused
+#' @param ... Additional parameters to be passed to plot
 setMethod("plot", "Zelig",
           function(x, ...) {
             x$graph()
           }
 )
 
+#' Variance-covariance method for Zelig objects
+#' @param object An Object of Class Zelig
+#' @param ... Additional parameters to be passed to vcov
 setMethod("vcov", "Zelig",
           function(object, ...) {
             object$getvcov()
           }
 )
 
+#' Method for extracting estimated coefficients from Zelig objects
+#' @param object An Object of Class Zelig
+#' @param ... Additional parameters to be passed to coef
 setMethod("coef", "Zelig",
           function(object, ...) {
             object$getcoef()
           }
 )
 
+#' Method for extracting estimated fitted values from Zelig objects
+#' @param object An Object of Class Zelig
+#' @param ... Additional parameters to be passed to fitted
 setMethod("fitted", "Zelig",
           function(object, ...) {
             object$getfitted()
           }
 )
 
+#' Method for getting predicted values from Zelig objects
+#' @param object An Object of Class Zelig
+#' @param ... Additional parameters to be passed to predict
 setMethod("predict", "Zelig",
           function(object, ...) {
             object$getpredict()
           }
 )
-
-#       idx <- match(names(.self$setx.labels),
-#                    names(.self$sim.out),
-#                    nomatch = 0) 
-#       names(.self$sim.out)[idx] <- .self$setx.labels[idx != 0]
